# About Dialects

<!-- TODO: add more here -->

Here is a list of applications and the dialects they use, as well as the names of the imports in EZRegex.

<!-- TODO: add more to this table -->
| Application        | Dialect    | Name       |
|--------------------|------------|------------|
| Python             | Python     | python     |
| JavaScript         | ECMAScript | javascript |
| R (grep*)          |            |            |
| R (stringr)        | PCRE2?     |            |
| Perl >= 7.3        | PCRE2      | PCRE2      |
| Perl < 7.3         | PCRE       | Not Implemented yet |
| Bash               |            |            |
| Excel Search       |            |            |
| Google Docs search |            |            |
| VSCode Search      |            |            |